"""Remove unused indexes in depends_on table

Revision ID: 3d0f03348c25
Revises: fcac91b2a3f1
Create Date: 2019-12-16 08:37:15.994395+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "3d0f03348c25"
down_revision = "fcac91b2a3f1"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index("depends_on_idx", table_name="depends_on")
    op.drop_index("depends_on_version_range_idx", table_name="depends_on")
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_index(
        "depends_on_version_range_idx", "depends_on", ["entity_id", "version_id", "version_range"], unique=False
    )
    op.create_index("depends_on_idx", "depends_on", ["entity_id", "version_id", "version_range"], unique=False)
    # ### end Alembic commands ###
