"""Add container image environment variables

Revision ID: cb86ec08e5ce
Revises: 081bee0d9587
Create Date: 2021-03-09 11:39:07.315261+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "cb86ec08e5ce"
down_revision = "081bee0d9587"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column("external_software_environment", sa.Column("env_image_name", sa.Text(), nullable=True))
    op.add_column("external_software_environment", sa.Column("env_image_tag", sa.Text(), nullable=True))
    op.add_column("software_environment", sa.Column("env_image_name", sa.Text(), nullable=True))
    op.add_column("software_environment", sa.Column("env_image_tag", sa.Text(), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("software_environment", "env_image_tag")
    op.drop_column("software_environment", "env_image_name")
    op.drop_column("external_software_environment", "env_image_tag")
    op.drop_column("external_software_environment", "env_image_name")
    # ### end Alembic commands ###
