"""Add parameters to deal with unsolved pacakges in adviser run

Revision ID: 125a71b49a50
Revises: 74254b596f00
Create Date: 2020-03-23 13:46:21.439043+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "125a71b49a50"
down_revision = "74254b596f00"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column("adviser_run", sa.Column("need_re_run", sa.Boolean(), nullable=True))
    op.add_column("adviser_run", sa.Column("re_run_adviser_id", sa.String(length=256), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("adviser_run", "re_run_adviser_id")
    op.drop_column("adviser_run", "need_re_run")
    # ### end Alembic commands ###
